@@ -21,7 +21,7 @@ LOG_LEVEL = 'DEBUG' if DEBUG else 'ERROR'
 
 LOGGING = {
     'version': 1,
-    'disable_existing_loggers': False,
+    'disable_existing_loggers': True,
     'formatters': {
         'standard': {
             'format': '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
@@ -41,9 +41,5 @@ LOGGING = {
             'level': LOG_LEVEL,
             'propagate': True
         },
-        'django.db.backends': {
-            'level': LOG_LEVEL,
-            'handers': ['default'],
-        },
     }
 }
