@@ -105,7 +105,11 @@ class Conexao(object):
 
     def request(self, metodo=TipoMetodo.post, segunda_tentativa=False, passo=None):
         url = self.define_url_com_autenticacao(atualiza_autenticacao=segunda_tentativa)
-        dados = self.servico.gerar_dados_de_envio(passo=passo)
+        dados = None
+        if self.tipo == TipoConexao.envio:
+            dados = self.servico.gerar_dados_de_envio(passo=passo)
+        if self.tipo == TipoConexao.retorno:
+            dados = self.servico.gerar_dados_de_envio()
         if dados:
             if type(dados) is dict:
                 self.dados_envio.update(dados)
