@@ -25,6 +25,10 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 pgc.pagamento_configuracao_desconto,
                 pgc.pagamento_configuracao_desconto_tipo,
                 pgc.pagamento_configuracao_desconto_valor,
+                pgc.pagamento_configuracao_quantidade_parcela_maxima,
+                pgc.pagamento_configuracao_quantidade_parcela_sem_juros,
+                pgc.pagamento_configuracao_juros_valor,
+                pgc.pagamento_configuracao_valor_minimo_parcela,
                 pgc.conta_id
            FROM configuracao.tb_pagamento as pg
            LEFT OUTER JOIN configuracao.tb_pagamento_configuracao as pgc on (pgc.pagamento_id = pg.pagamento_id AND pgc.conta_id=%s)
@@ -87,6 +91,13 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             cls.QUERY_CONFIGURACOES_ATIVAS.format((" AND pg.pagamento_id=%s" if pagamento_id else '')), parametros
         )
 
+    @property
+    def valor_minimo_da_parcela(self):
+        valor = getattr(self, "pagamento_configuracao_valor_minimo_parcela", 0.0)
+        if valor > 0:
+            return float(valor)
+        return float(self.valor_minimo_parcela or 0.0)
+
     def to_dict(self, com_configuracao=True, plano_indice=None, soh_habilitados=False):
         forma_pagamento = {
             "id": self.id,
@@ -97,7 +108,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             "imagem_loja": self.imagem_loja,
             "plano_indice": self.plano_indice,
             "parcelas": [{"fator": float(parcela.fator), "numero_parcelas": parcela.numero_parcelas} for parcela in self.parcelas.all()],
-            "valor_minimo_parcela": float(self.valor_minimo_parcela or 0.0)
+            "valor_minimo_parcela": self.valor_minimo_da_parcela
         }
         if com_configuracao:
             if self.pagamento_configuracao_desconto:
@@ -106,6 +117,12 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 forma_pagamento["desconto_valor"] = '{0:.2f}'.format(self.pagamento_configuracao_desconto_valor)
             forma_pagamento["ativo_para_a_conta"] = self.pagamento_configuracao_ativo
             forma_pagamento["configurado"] = self.configurado is not None
+            forma_pagamento["maximo_parcelas"] = self.pagamento_configuracao_quantidade_parcela_maxima
+            forma_pagamento["parcelas_sem_juros"] = self.pagamento_configuracao_quantidade_parcela_sem_juros
+            juros_valor = self.pagamento_configuracao_juros_valor
+            if not juros_valor:
+                juros_valor = 0.0
+            forma_pagamento["juros_valor"] = float(juros_valor)
             if plano_indice:
                 try:
                     plano_indice = int(plano_indice)
@@ -199,10 +216,9 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
         except AttributeError:
             raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoEnvio.".format(self.meio_pagamento))
 
-    @property
-    def selecao(self):
+    def selecao(self, dados=None):
         try:
-            return self.plugin_configuracao.MeioPagamentoSelecao(self)
+            return self.plugin_configuracao.MeioPagamentoSelecao(self, dados)
         except AttributeError, ex:
             if "NoneType" in unicode(ex):
                 raise
