@@ -17,5 +17,9 @@ class Pedido(PedidoVenda):
     def provavel_data_entrega(self):
         return self.data_criacao + datetime.timedelta(days=self.prazo_entrega)
 
+    @property
+    def provavel_data_envio(self):
+        return self.data_criacao + datetime.timedelta(days=self.prazo_envio)
+
     def pedido_venda_pagamento_da_forma_de_pagamento(self, pagamento_id):
         return PedidoVendaFormaPagamento.objects.filter(pedido=self, conta=self.conta, pagamento_id=pagamento_id)
