@@ -4,20 +4,22 @@ import requests
 from pagador import settings
 
 
-def grava_evidencia_retorno(meio_pagamento, dados, conta_id, pedido_numero, tipo_evidencia="pagador-retorno", registrado=False, enviado=None):
+def grava_evidencia_retorno(meio_pagamento, dados, conta_id, pedido_numero, tipo_evidencia="retorno", registrado=False, enviado=None):
+
     evidencia = {
-        "tipo_evidencia": tipo_evidencia,
+        "index": "pagador",
+        "tipo_evidencia": meio_pagamento + '-' + tipo_evidencia,
         "evidencia": {
             "conta_id": conta_id,
             "pedido_numero": pedido_numero,
-            "meio_pagamento": meio_pagamento,
             "recebido": {
                 "dados": dados
             },
             "enviado": enviado
         }
     }
-    if tipo_evidencia == "pagador-retorno":
+
+    if tipo_evidencia == "retorno":
         evidencia["evidencia"]["found"] = registrado
 
     try:
