@@ -43,11 +43,13 @@ class Formatador(object):
             return Decimal(0)
 
     @classmethod
-    def formata_decimal(cls, valor, como_float=False, como_int=False):
+    def formata_decimal(cls, valor, como_float=False, como_int=False, em_centavos=False):
         if como_float:
             return float('{0:.2f}'.format(valor))
         if como_int:
             return int(valor)
+        if em_centavos:
+            return int(valor * 100)
         return '{0:.2f}'.format(valor)
 
     @classmethod
@@ -135,3 +137,15 @@ class Formatador(object):
             return normalize('NFKD', texto.decode('utf-8')).encode('ASCII', 'ignore')
         except UnicodeEncodeError:
             return normalize('NFKD', texto).encode('ASCII', 'ignore')
+
+    @classmethod
+    def trata_nome(cls, nome):
+        if nome:
+            nome = nome.strip()
+        if len(nome.split(" ")) < 2:
+            nome = u"{} x".format(nome)
+        if "&" in nome or "?" in nome:
+            nome = nome.replace("&", "E")
+        if "?" in nome:
+            nome = nome.replace("?", " ")
+        return nome
